/**
 * 
 */
package com.caringo.client;

import java.io.OutputStream;
import com.caringo.client.request.ScspRequestHandler;
/**
 * Represents an SCSP APPEND command.<br>
 * <p>
 * Copyright (c) 2010 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>
 * 
 * @author pray
 * @created Jan 1, 2010
 * @id $Id: ScspAggregateInfo.java 52121 2012-08-28 17:31:56Z jafshar $
 */
public class ScspAggregateInfo extends ScspBaseStreamCommand {

	private OutputStream outputStream;
	
	// Package-private
	// 
	// Construct a ScspAggregateInfo object with uuid and output stream
	//
	ScspAggregateInfo(ScspRequestHandler client, String UUID, OutputStream outputStream) {
		super(client, UUID);
		this.outputStream = outputStream;
	}
	
    /**
     * Return the output stream. This will likely be in a very different state after execution.
     * 
     * @return the output stream.
     */
    public OutputStream getOutputStream() {
        return outputStream;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.caringo.client.ScspCommand#execute()
     */
    @Override
    public ScspResponse execute() throws ScspExecutionException {
        BasicScspResponseOutputStream output = new BasicScspResponseOutputStream(getOutputStream());
        getQueryArgs().setValue("indirect", "HEAD");
        getPreparedClient().read(makePath(), getHeaders(), getQueryArgs().toQueryArgString(), output);
        int httpResponseStatusCode = output.getStatusCode();
        ScspResponse.ScspResultCode resultCode = ScspResponse.ScspResultCode.ScspRCSuccess;
        // Check for only 200 OK. Since the response is built on the fly, things like conditional reads or hashes don't make sense.
        if (httpResponseStatusCode != 200) {
            resultCode = ScspResponse.ScspResultCode.ScspRCFailure;
        }
        return new ScspResponse(resultCode, httpResponseStatusCode, output.getStatusLine(), output.getHeaders(), output
                .getBodyString(), output.getRetryCount());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.caringo.client.ScspCommand#validate()
     */
    @Override
    public boolean validate() {
        boolean result = super.validate() && 
        				 !getQueryArgs().containsName("hash") && // hashes can't work on aggregate info.
        				 !getQueryArgs().containsName("hashtype") &&
        				 !getQueryArgs().containsName("newhashtype") &&
        				 !getQueryArgs().containsName("countReps") &&
        				 !getQueryArgs().containsName("validate") &&
        				 ScspValidations.validateAlias(getQueryArgs(), false); // Suppose somebody could set an manifest using an anchor stream
        return result;
    }
}
