package com.caringo.client;

import com.caringo.client.request.ScspRequestHandler;

/**
 * Abstract base class for all SCSP commands that operate on a known stream.<br>
 * <p>
 * Copyright (c) 2009 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>
 * 
 * @author pray
 * @created September 22, 2009
 * @id ${Id}
 */

public abstract class ScspBaseStreamCommand extends ScspCommand {

    private String UUID;

    // Protected
    //
    // Construct a ScspBaseStreamCommand object with a request handler and UUID.
    // 
    protected ScspBaseStreamCommand(ScspRequestHandler client, String UUID) {
        super(client);
        this.UUID = UUID;
    }

    /**
     * Return the stream UUID.
     * 
     * @return the UUID.
     */
    @Deprecated
    public String getUUID() {
        return UUID;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.caringo.client.ScspCommand#validate()
     */
    @Override
    public boolean validate() {
        return super.validate() &&
               ScspValidations.validateHexString(UUID, 32);
    }
    
    /*
     * (non-Javadoc)
     * 
     * build the path from the UUID and path
     */
    protected String makePath() {
    	String res = getPath();
        String uuid = getUUID();
    	if (res.length() > 0 && uuid.length() > 0) {
    		res += "/";
    	}
    	return res += uuid;
    }
}
