/**
 * 
 */
package com.caringo.client;

import java.io.InputStream;

import com.caringo.client.request.ScspRequestHandler;

/**
 * Abstract base class for all SCSP commands that write to a known stream.<br>
 * <p>
 * Copyright (c) 2009 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>
 * 
 * @author pray
 * @created September 22, 2009
 * @id ${Id}
 */
public abstract class ScspBaseStreamRewriteCommand extends ScspBaseStreamCommand {

    private InputStream inputStream;
    private long streamLength;

    // Protected
    //
    // Construct a ScspBaseStreamRewriteCommand object with a request handler, UUID, input stream, and stream length.
    // 
    protected ScspBaseStreamRewriteCommand(ScspRequestHandler client, String UUID, InputStream inputStream, long streamLength) {
        super(client, UUID);
        this.inputStream = inputStream;
        this.streamLength = streamLength;
    }

    /**
     * Return the source input stream. Note that execute may change the state of the input stream.
     * 
     * @return the input stream.
     */
    public InputStream getInputStream() {
        return inputStream;
    }

    /**
     * Return the length of the input stream.
     * 
     * @return The length of the input stream.
     */
    public long getStreamLength() {
        return streamLength;
    }

    /*
     * (non-Javadoc)
     * 
     * Execute a rewrite command. Override this to execute a particular HTTP command.
     * Response output will be written to output, and the content type from the command headers
     * will be passed as the contentType argument.
     */
    protected abstract void executeRewrite(BasicScspResponseOutputStream output, String contentType) throws ScspExecutionException;

    /*
     * (non-Javadoc)
     * 
     * @see com.caringo.client.ScspCommand#execute()
     */
    @Override
    public ScspResponse execute() throws ScspExecutionException {
        BasicScspResponseOutputStream output = new BasicScspResponseOutputStream(null);
        String contentType = "";
        if (getHeaders().containsName("Content-type")) {
            contentType = getHeaders().getHeaderValues("Content-Type").get(0);
        }
        executeRewrite(output, contentType);
        int httpResponseStatusCode = output.getStatusCode();
        ScspResponse.ScspResultCode resultCode = ScspResponse.ScspResultCode.ScspRCSuccess;
        if (httpResponseStatusCode != 201 && httpResponseStatusCode != 202) { // success code is 201 or 202
            resultCode = ScspResponse.ScspResultCode.ScspRCFailure;
        }
        return new ScspResponse(resultCode, httpResponseStatusCode, output.getStatusLine(), output.getHeaders(), output
                .getBodyString(), output.getRetryCount());
    }

}
