package com.caringo.client;

import com.caringo.client.request.ScspRequestHandler;


/**
 * Represents an SCSP COPY command.<br>
 * <p>
 * Copyright (c) 2009 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>
 * 
 * @author pray
 * @created September 20, 2009
 * @id $Id: ScspCopy.java 52121 2012-08-28 17:31:56Z jafshar $
 */
public class ScspCopy extends ScspBaseStreamCommand {

    // Package-private
    //
    // Construct a ScspCopy object with a request handler and UUID.
    // 
    ScspCopy(ScspRequestHandler client, String UUID) {
        super(client, UUID);
    }

    /* (non-Javadoc)
     * @see com.caringo.client.ScspCommand#execute()
     */
    @Override
    public ScspResponse execute() throws ScspExecutionException {

        BasicScspResponseOutputStream output = new BasicScspResponseOutputStream(null); // no body to write
        getQueryArgs().setValue("alias","yes");
        getPreparedClient().copy(makePath(), getHeaders(), getQueryArgs().toQueryArgString(), output);
        int httpResponseStatusCode = output.getStatusCode();
        ScspResponse.ScspResultCode resultCode = ScspResponse.ScspResultCode.ScspRCSuccess;
        if (httpResponseStatusCode != 201 && httpResponseStatusCode != 202) {
            resultCode = ScspResponse.ScspResultCode.ScspRCFailure;
        }
        return new ScspResponse(resultCode, httpResponseStatusCode, output.getStatusLine(), output.getHeaders(), output.getBodyString(), output.getRetryCount());
    }
    
    /* (non-Javadoc)
     * @see com.caringo.client.ScspCommand#validate()
     */
    @Override
    public boolean validate() {
       boolean mutable = getQueryArgs().containsName("alias") && getQueryArgs().getValue("alias").compareTo("yes") == 0;
       return super.validate() &&
            getHeaders().getNamesWithPrefix("Castor-System-").size() == 0 &&
            ScspValidations.validateReplicateOnWrite(getQueryArgs()) &&
            ScspValidations.validateHashType(getQueryArgs(), false) &&
            ScspValidations.validateAlias(getQueryArgs(), false) && 
            ScspValidations.validateContentDisposition(getHeaders()) &&
            ScspValidations.validateContentType(getHeaders()) &&
            ScspValidations.validateAllow(getHeaders(), true);
    }
}
