/**
 * 
 */
package com.caringo.client;

import com.caringo.client.request.ScspRequestHandler;


/**
 * Represents an SCSP Node Status command.<br>
 * 
 * Equivalent to an SCSP INFO command with an empty UUID.
 * <p>
 * Copyright (c) 2009 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>
 * 
 * @author pray
 * @created September 20, 2009
 * @id $Id: ScspNodeStatus.java 52121 2012-08-28 17:31:56Z jafshar $
 */
public final class ScspNodeStatus extends ScspCommand {

    // Package-private
    //
    // Construct a ScspNodeStatus object with a request handler.
    // 
    ScspNodeStatus(ScspRequestHandler client) {
        super(client);
    }

    /* (non-Javadoc)
     * @see com.caringo.client.ScspCommand#execute()
     */
    @Override
    public ScspResponse execute() throws ScspExecutionException {
        // Note that this issues against current redirected node. Could preferentially query 
        // against locator node

        BasicScspResponseOutputStream output = new BasicScspResponseOutputStream(null); // no body to write
        getPreparedClient().read(null, getHeaders(), getQueryArgs().toQueryArgString(), output);
        int httpResponseStatusCode = output.getStatusCode();
        ScspResponse.ScspResultCode resultCode = ScspResponse.ScspResultCode.ScspRCSuccess;
        if (httpResponseStatusCode != 200) {
            resultCode = ScspResponse.ScspResultCode.ScspRCFailure;
        }
        return new ScspResponse(resultCode, httpResponseStatusCode, output.getStatusLine(), output.getHeaders(), output.getBodyString(), output.getRetryCount());
    }
    
    /* (non-Javadoc)
     * @see com.caringo.client.ScspCommand#validate()
     */
    @Override
    public boolean validate() {
        return true;
    }   
}
