/**
 * 
 */
package com.caringo.client;

import java.io.InputStream;

import com.caringo.client.request.ScspRequestHandler;

/**
 * Represents an SCSP UPDATE command.<br>
 * <p>
 * Copyright (c) 2009 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>
 * 
 * @author pray
 * @created September 20, 2009
 * @id $Id: ScspUpdate.java 52121 2012-08-28 17:31:56Z jafshar $
 */
public class ScspUpdate extends ScspBaseStreamRewriteCommand {

    // Package-private
    //
    // Construct a ScspUpdate object with a request handler, UUID, input stream, and input data length.
    // 
    ScspUpdate(ScspRequestHandler client, String UUID, InputStream inputStream, long streamLength) {
        super(client, UUID, inputStream, streamLength);
    }

    // override ScspBaseStreamRewriteCommand.executeRewrite()
    @Override
    protected void executeRewrite(BasicScspResponseOutputStream output, String contentType) throws ScspExecutionException {
        getPreparedClient().update(makePath(), getInputStream(), getStreamLength(), contentType, getHeaders(),
                getQueryArgs().toQueryArgString(), output);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.caringo.client.ScspCommand#validate()
     */
    @Override
    public boolean validate() {
       boolean result = super.validate() &&
                         getHeaders().getNamesWithPrefix("Castor-System-").size() == 0 &&
                         ScspValidations.validateContentType(getHeaders()) &&
                         ScspValidations.validateReplicateOnWrite(getQueryArgs()) &&
                         ScspValidations.validateHashType(getQueryArgs(), false) &&
                         ScspValidations.validateContentDisposition(getHeaders()) &&
                         ScspValidations.validateAlias(getQueryArgs(),false) && //Update doesn't have to have alias
                         ScspValidations.validateAllow(getHeaders(), true);
        return result;
    }

}
