/*
 * Copyright (c) 2007 by Caringo, Inc. -- All rights reserved
 * Caringo Confidential and Proprietary
 */
package com.caringo.client.locate;

import java.io.IOException;
import java.net.InetSocketAddress;

/**
 * 
 * Class: Locator <br>
 * Package: com.caringo.client.locate<br>
 * Description: Locator provides an interface for CAStor cluster node discovery. It will provide an InetSocketAddress with which
 * they may make initial contact with the cluster. Clients should provide feedback to the Locator so that it can maintain its cache
 * of known good nodes. When they find that a node that the Locator has given them is no longer good, it will be removed. Also, if a
 * new node is found good, it should be added.<br>
 * <br>
 * Copyright (c) 2008 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>

 * 
 * @author jmike
 * @created Apr 11, 2007
 */
public interface Locator {

    /**
     * This method needs a description.
     * 
     * @throws IOException
     *             If an input or output exception occurs.
     */
    public void start() throws IOException;

    /**
     * This method needs a description.
     */
    public void stop();

    /**
     * This method needs a description.
     * 
     * @return An <code>InetSocketAddress</code> object.
     */
    public InetSocketAddress locate();

    /**
     * This method needs a description.
     * 
     * @return An array of <code>InetSocketAddress</code> objects.
     */
    public InetSocketAddress[] locateAll();

    /**
     * This method needs a description.
     */
    public void foundAlive(InetSocketAddress addr);

    /**
     * This method needs a description.
     */
    public void foundDead(InetSocketAddress addr);

}
