package com.caringo.client.locate;

import java.lang.RuntimeException;
import java.util.HashMap;

public class NoCastorNodesLocatedException extends RuntimeException {
    // Errors returnable from the proxy
    public static final String NO_NODES = "no-nodes";
    public static final String BAD_SUBNET = "bad-subnet";
    public static final String BAD_CLUSTER = "bad-cluster";
    public static final String DISABLED = "disabled";
    
    public static final HashMap<String, String> ERRORS = new HashMap<String, String>() {
        {
            put(NO_NODES, "The proxy itself currently has an empty node list. This can happen, for example, if the cluster is temporarily offline, disconnected, or is being rebooted.");
            put(BAD_SUBNET, "The request was made from a subnet from which the node IP addresses are not routable.");
            put(BAD_CLUSTER, "The cluster name supplied in the Scsp-Proxy-Cluster header did not match the currently configured cluster of the proxy.");
            put(DISABLED, "The proxy has been configured not to return IP address information about the CAStor cluster.");
        }
    };
    
    protected String reason;
    
    public NoCastorNodesLocatedException(String reason) {
        super(reason);
        this.reason = reason;
    }
    
    public String getFriendlyError() {
        if (ERRORS.containsKey(reason)) {
            return ERRORS.get(reason);
        }
        
        return "";  // unknown error reason, that's the best we can offer
    }
    
    public String getReason() {
        return reason;
    }
}
