package com.caringo.client.locate;

import org.apache.log4j.Logger;

/**
 * Pair is a class that stores a typed pair.
 * 
 * Copyright (c) 2006 by Caringo, Inc. -- All rights reserved Caringo<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>

 * @author jmike
 * @created Sep 24, 2006
 * @id $Id: Pair.java 3023 2006-11-13 04:32:05Z jmike $
 */
public class Pair<T1, T2> {
    private static final Logger logger = Logger.getLogger(Pair.class);
    
    public T1 left;
    public T2 right;

    /**
     * Constructor.
     * 
     * @param left - The left side element.
     * @param right - The right side element.
     */
    public Pair(T1 left, T2 right) {
        this.left = left;
        this.right = right;
    }

    /**
     * Generate a hash code.
     * 
     * @return The generated hash code.
     */
    @Override
    public int hashCode() {
        final int PRIME = 31;
        int result = 1;
        result = PRIME * result + ((left == null) ? 0 : left.hashCode());
        result = PRIME * result + ((right == null) ? 0 : right.hashCode());
        return result;
    }

    /**
     * Compare this object against another.
     * 
     * @param obj - An object to compare against.
     * @return True if the object is equal to this object.
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        final Pair<?, ?> other = (Pair<?, ?>) obj;
        if (left == null) {
            if (other.left != null)
                return false;
        } else if (!left.equals(other.left))
            return false;
        if (right == null) {
            if (other.right != null)
                return false;
        } else if (!right.equals(other.right))
            return false;
        return true;
    }

    /**
     * Get the left side element.
     * 
     * @return The left side element.
     */
    public T1 getKey() {
        return left;
    }

    /**
     * Get the right side element.
     * 
     * @return The right side element.
     */
    public T2 getValue() {
        return right;
    }
  
    /**
     * Stringify this pair.
     * 
     * @return A <code>String</code> representation of this pair.
     */
    @Override
    public String toString() {
        return "["+this.left.toString()+","+this.right.toString()+"]";
    }
    
    /**
     * Method description goes here.
     * 
     * @param object - Parameter description goes here.
     * @return True or false.
     */
    public boolean contained(Integer object) {
        logger.debug("[left:"+left+"] [right:"+right+"] [value:"+object+"]");
        if (object >= (Integer) this.left && object <= (Integer)this.right) {            
            logger.debug("contained --> true");
            return true;
        } 
        logger.debug("contained --> false");
        return false;
    }
    
    /**
     * Method description goes here.
     * 
     * @param object - Parameter description goes here.
     * @return True or false.
     */
    public boolean contained(Long object) {
        logger.debug("[left:"+left+"] [right:"+right+"] [value:"+object+"]");
        if (object >= (Long) this.left && object <= (Long)this.right) {            
            logger.debug("contained --> true");
            return true;
        } 
        logger.debug("contained --> false");
        return false;
    }

}
