/**
 * 
 */
package com.caringo.client.request;

import com.caringo.client.locate.Locator;
import java.util.LinkedList;
import java.net.InetSocketAddress;
import java.io.IOException;

/**
 * Copyright (c) 2010 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>
 * 
 * @author pray
 * @created Jan 1, 2010
 * @id $Id: LocatorRedirectHandler.java 52121 2012-08-28 17:31:56Z jafshar $
 */
public class LocatorRedirectHandler implements Locator {
    
    private Locator locator;
    private LinkedList<InetSocketAddress> redirects;

    public LocatorRedirectHandler(Locator locator) {
        this.locator = locator;
        this.redirects = new LinkedList<InetSocketAddress>();
    }

    public Locator getLocator() {
        return locator;
    }
    
    public synchronized void notifyRedirect(InetSocketAddress originalNode, InetSocketAddress redirectedNode) {
        redirects.remove(originalNode);
        redirects.add(redirectedNode);
    }
    
    public synchronized void foundDead(InetSocketAddress node) {
        if (redirects.contains(node)) {
            redirects.remove(node);
        }
        else {
            locator.foundDead(node);
        }
    }
    public synchronized void foundAlive(InetSocketAddress node) {
        if (!redirects.contains(node)) {
            locator.foundAlive(node);
        }
    }
    
    public synchronized InetSocketAddress locate() {
        if (redirects.size() > 0) {
            return redirects.element(); // get head
        }
        else {
            return locator.locate();
        }
    }
    
    public InetSocketAddress[] locateAll() {
        return locator.locateAll();
    }
    
    public void start() throws IOException {
        locator.start();
    }
    public void stop() {
        locator.stop();
    }
}
