/*
 * Copyright (c) 2007 by Caringo, Inc. -- All rights reserved
 * Caringo Confidential and Proprietary
 */
package com.caringo.client.request;

import java.io.IOException;

import org.apache.commons.httpclient.Header;
import org.apache.commons.httpclient.HttpMethod;

import com.caringo.client.ScspHeader;
import com.caringo.client.ScspHeaders;

/**
 * 
 * Class: MethodFactory <br>
 * Package: com.caringo.client.ng<br>
 * 
 * Provides an interface for derived Factories to generate various HttpMethod objects.
 * 
 * <br>
 * Copyright (c) 2008 by Caringo, Inc. -- All rights reserved<br>
 * This is free software, distributed under the terms of the New BSD license.<br>
 * See the LICENSE.txt file included in this archive.<br>
 * <br>
 * @author  jmcswain
 * @created Jul 23, 2008
 */
abstract class MethodFactory {
    protected ScspHeaders reqHeaders;

    MethodFactory(ScspHeaders headers) {
        this.reqHeaders = headers;
    }
    
    protected abstract HttpMethod getMyMethod();
    
    protected HttpMethod addHeadersToMethod(HttpMethod method) {
        // copy over headers
        if (reqHeaders != null) {
            if (reqHeaders.containsName("Host")) {
                String hostHeader = reqHeaders.getHeaderValues("Host").get(0);
                
                method.getParams().setVirtualHost(hostHeader);
            }
            
            for (ScspHeader header:reqHeaders.toHeaderList()) {
                method.addRequestHeader(new Header(header.getName(),header.getValue()));
            }
        }
        return method;
    }
    
    HttpMethod makeMethod() throws IOException {
        return addHeadersToMethod(getMyMethod());
    }
}
