package com.caringo.enumerator;


/**
 * Enum class for the types of CAStor cluster events reported by an Object Enumerator of type "events" 
 * 
 * Copyright (c) 2010 by Caringo, Inc. -- All rights reserved
 * Caringo Confidential and Proprietary
 * 
 * @author jcasey
 * @created January 21, 2010
 */
public enum EnumeratorEventType {

	ENUM_EVENT_DELETED("deleted", 1),
	ENUM_EVENT_CREATED("created", 2),
	ENUM_EVENT_UPDATED("updated", 4);
	
	
	private final int number;
	private final String name;
	
	EnumeratorEventType(String name, int number){
		this.name = name;
		this.number = number;
	}
	
	/**
	 * 
	 * @return name
	 */
	public String getName() {
		
		return this.name;
	}
	
	/**
	 * 
	 * @return number
	 */
	public int getNumber() {
		
		return this.number;
	}
	
	/**
	 * Return a string version of this enum
	 * 
	 */
	@Override
    public String toString() {
        return name + " (" + number + ")";
    }
	
	/**
	 * Return the EnumeratorEventType corresponding to the argument
	 * 
	 * @param num -
	 * 				The number of the EnumeratorEventType to return
	 * @return EnumeratorEventType
	 */
	public static EnumeratorEventType getEventTypeByNum(int num) {
        for (EnumeratorEventType type : EnumeratorEventType.values()) {
            if (type.getNumber() == num) {
                return type;
            }
        }
        return null;
    }

}
