package com.caringo.enumerator;

import java.util.ArrayList;
import java.util.Iterator;

import com.caringo.client.ScspHeader;

/**
 * Concrete class for the entry returned by an ObjectEnumerator of type "metadata" 
 * 
 * Copyright (c) 2010 by Caringo, Inc. -- All rights reserved
 * Caringo Confidential and Proprietary
 * 
 * @author jcasey
 * @created January 21, 2010
 */
public class EnumeratorMetadataEntry extends EnumeratorEntry {
	
	private String uuid;
	private ArrayList<ScspHeader> headers;
	
	/**
	 * Constructor
	 * 
	 * @param uuid
	 * @param scspHeaders
	 */
	public EnumeratorMetadataEntry(String uuid, ArrayList<ScspHeader> scspHeaders) {
		
		this.uuid = uuid;
		this.headers = scspHeaders;
	}

	/**
	 * Returns true if this EnumeratorMetadataEntry is equivalent to the argument
	 */
	@Override
	public boolean equals(Object other) {
		
		if (other == null) {
			return false;
		}
		
		if (other instanceof EnumeratorMetadataEntry) {
			EnumeratorMetadataEntry otherEntry = (EnumeratorMetadataEntry) other;
			if (this.uuid.equals(otherEntry.getUuid())) {
				return this.compareScspHeaders(this.getScspHeaders(), otherEntry.getScspHeaders());
			}
		}
		
		return false;
	}

	/**
	 * Helper function which compares two sets of ScspHeaders
	 * 
	 * @param ourHeaders
	 * @param theirHeaders
	 * @return
	 */
	private boolean compareScspHeaders(ArrayList<ScspHeader> ourHeaders, ArrayList<ScspHeader> theirHeaders) {
		
		if (ourHeaders.size() != theirHeaders.size()){
			return false;
		}
		
		for (Iterator<ScspHeader> ourHeadersIter = ourHeaders.iterator(); ourHeadersIter.hasNext();) {
			ScspHeader ourHeader = ourHeadersIter.next();
			boolean matched = false;
			for (Iterator<ScspHeader> theirHeadersIter = theirHeaders.iterator(); theirHeadersIter.hasNext();) {
				ScspHeader theirHeader = theirHeadersIter.next();
				if (ourHeader.equals(theirHeader)) {
					matched = true;
				}
			}
			if (! matched){
				return false;
			}
		}
		
		return false;
	}

	/**
	 * 
	 * @return uuid
	 */
	@Override
	public String getUuid() {
		
		return this.uuid;
	}
	
	/**
	 * 
	 * @return headers
	 */
	public ArrayList<ScspHeader> getScspHeaders(){
		
		return this.headers;
	}

	/**
	 * Return a string representation of this entry
	 */
	@Override
	public String toString() {
		
		String hdrString = "";
		hdrString += "[" + this.uuid + "]\n";
		for (Iterator<ScspHeader> headersIterator = headers.iterator(); headersIterator.hasNext();){
			ScspHeader header = headersIterator.next();
			hdrString += "[" + header.toString() + "]";
		}
		
		return hdrString;
	}

}
