package com.caringo.enumerator;

/**
 * Enum class for the query arguments that can be passed to an Object Enumerator
 * 
 * Copyright (c) 2010 by Caringo, Inc. -- All rights reserved
 * Caringo Confidential and Proprietary
 * 
 * @author jcasey
 * @created January 20, 2010
 */
public enum EnumeratorQueryArgs {
	
	//
    TYPE("type", true, false),
    //
    START_DATE("start", true, false),
    //
    END_DATE("end", true, false),
    //
    UPTIME("uptime", false, true),
    //
    BACKLOG("backlog", false, true),
    //
    IN_PROGRESS("inProgress", false, true),
    //
    DROPPED("dropped", false, true),
    //
    MAX_ITEMS("maxItems", true, true),
    //
    VERSION("version", true, true),
    //
    CONTEXT("context", true, true),
    //
    OFFLINE_AFTER("offlineAfter", true, true),
    //
    ERR_OFFLINE_AFTER("errOfflineAfter", true, true),
    //
    TIMEOUT("timeout", true, true);
    
    private final String name;
    private final boolean validForStart;
    private final boolean validForNext;
    
    EnumeratorQueryArgs(String name, boolean allowedForStart, boolean allowedForNext) {
    	
        this.name = name;
        this.validForStart = allowedForStart;
        this.validForNext = allowedForNext;
    }
    
    public String getName() {
        return name;
    }

    @Override
    public String toString() {
        return name;
    }
    
    /**
     * Returns true if the argument is in the enum list
     * 
     * @param argName
     * @return boolean
     */
    public static boolean isValidQueryArg(String argName){
    	
    	if (argName == null){
    		return false;
    	}
    	
    	for (EnumeratorQueryArgs arg : EnumeratorQueryArgs.values()){
    		if (arg.getName().equals(argName)){
    			return true;
    		}
    	}
    	
    	return false;    	
    }
    
    /**
     * Returns true if the argument is in the enum list 
     * and can be passed to the enumerator start method
     * 
     * @param argName
     * @return boolean
     */
    public static boolean isValidQueryArgForStart(String argName){
    	
    	if (argName == null){
    		return false;
    	}
    	
    	for (EnumeratorQueryArgs arg : EnumeratorQueryArgs.values()){
    		if (arg.getName().equals(argName) && arg.validForStart){
    			return true;
    		}
    	}
    	
    	return false;    	
    }
    
    /**
     * Returns true if the argument is in the enum list 
     * and can be passed to the enumerator next method
     * 
     * @param argName
     * @return boolean
     */
    public static boolean isValidQueryArgForNext(String argName){
    	
    	if (argName == null){
    		return false;
    	}
    	
    	for (EnumeratorQueryArgs arg : EnumeratorQueryArgs.values()){
    		if (arg.getName().equals(argName) && arg.validForNext){
    			return true;
    		}
    	}
    	
    	return false;    	
    }

}
